@@ -12,31 +12,44 @@ des calculs sans craindre les ralentissements réseau. Toutes
 les vérifications se font donc en local.
 """
 
+from .consts import FUPDB_CREDENTIALS
+
+import records
+
 
 __all__ = [
+    'database_url',
     'record_customer',
     'apply_product_policies',
     'update_customer_cdr'
     ]
 
 
-def record_customer(product, infos):
-    from .consts import DB
-    key = 'customer:{name}'.format(name=infos['name'])
-    DB.hmset(
-        key,
-        {
-            'product': infos['product'],
-            'refnum': infos['refnum']
-            }
+def database_url(**kwargs):
+    url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+        eng=kwargs.get('engine'),
+        user=kwargs.get('user'),
+        password=kwargs.get('password'),
+        host=kwargs.get('host'),
+        port=kwargs.get('port'),
+        name=kwargs.get('name')
         )
-    policies = product.policies
-    for policy_name in policies:
-        key = 'fup:{customer_name}:{policy_name}'.format(
-            customer_name=infos['name'],
-            policy_name=policy_name
+    return url
+
+
+def record_customer(infos):
+    url = database_url(**FUPDB_CREDENTIALS)
+    with records.Database(url) as db:
+        sql = (
+            "INSERT INTO customer (name, refnum, product) "
+            "VALUES (:name, :refnum, :product)"
+            )
+        db.query(
+            sql,
+            name=infos['name'],
+            refnum=infos['refnum'],
+            product=infos['product']
             )
-        DB.hset(key, 'status', False)
 
 
 def apply_product_policies(for_real, customer):
